# Client software for the EBRAINS Neuromorphic Computing Platform, developed by the Human Brain Project


For documentation, see https://electronicvisions.github.io/hbp-sp9-guidebook/

For more information about EBRAINS, see https://ebrains.eu/
For more information about the Human Brain Project, see https://www.humanbrainproject.eu/


[![Build Status](https://travis-ci.org/HumanBrainProject/hbp-neuromorphic-client.svg?branch=master)](https://travis-ci.org/HumanBrainProject/hbp-neuromorphic-client)

This software was developed in the Human Brain Project,
funded from the European Union’s Horizon 2020 Framework Programme for Research and Innovation
under Specific Grant Agreements No. 720270, No. 785907 and No. 945539 (Human Brain Project SGA1, SGA2 and SGA3).
